Module git

Module git 

Functions

hash
Check if the codebase is built under a Git repository and return the hash of the current commit as Vec<u8>.
hash_str
short_hash
short_hash_str
version
with_short_hash