Refs

Enum Refs 

pub enum Refs<'a, T> {
    Ref(&'a T),
    Arc(Arc<T>),
    Rc(Rc<T>),
    Box(Box<T>),
}
Enum used to represent a concrete varying pointer type which only needs to be accessed by ref. We avoid adding a Val(T) variant in order to keep the size of the enum minimal

Variants



Ref(&'a T)



Arc(Arc<T>)



Rc(Rc<T>)



Box(Box<T>)