RfRwLock

Struct RfRwLock 

pub struct RfRwLock { /* private fields */ }
Readers-first Reader-writer Lock. If the lock is acquired by readers, then additional readers will always be able to acquire the lock as well even if a writer is already in the queue. Note that this makes it safe to make recursive read calls.

We currently only use this lock over an empty tuple, however it can easily contain data by using UnsafeCell<T> and passing it to the various guards with or without mutable access

Implementations

Source

impl RfRwLock

pub fn new() -> Self

pub async fn read(&self) -> RfRwLockReadGuard<'_>

pub fn blocking_read(&self) -> RfRwLockReadGuard<'_>

pub async fn read_owned(self: Arc<Self>) -> RfRwLockOwnedReadGuard

pub async fn write(&self) -> RfRwLockWriteGuard<'_>

pub fn blocking_write(&self) -> RfRwLockWriteGuard<'_>

pub async fn write_owned(self: Arc<Self>) -> RfRwLockOwnedWriteGuard