Module git
kaspa_
utils
0.15.0
Module git
Module Items
Functions
In crate kaspa_
utils
kaspa_utils
Module
git
Functions

hash
Check if the codebase is built under a Git repository and return the hash of the current commit as
Vec<u8>
.
hash_
str
short_
hash
short_
hash_
str
version
with_
short_
hash